package
Net::eNom;

use strict;
use warnings;
use utf8;
use Any::Moose;

extends 'WWW::eNom';

our $VERSION = 'v1.0.1'; # VERSION

1;
